@@ -85,7 +85,7 @@ Mstep <- function(pars, est, longpars, ngroups, J, gTheta, itemloc, PrepList, L,
             opt <- try(Mstep.NR(p=p, est=est, longpars=longpars, pars=pars, ngroups=ngroups,
                                 J=J, gTheta=gTheta, PrepList=PrepList, L=L,  ANY.PRIOR=ANY.PRIOR,
                                 constrain=constrain, LBOUND=LBOUND, UBOUND=UBOUND, SLOW.IND=SLOW.IND,
-                                itemloc=itemloc, DERIV=DERIV, rlist=rlist, TOL=TOL, control=control), TRUE)
+                                itemloc=itemloc, DERIV=DERIV, rlist=rlist, control=control), TRUE)
         } else if(Moptim %in% c('solnp', 'alabama')){
             optim_args <- list(CUSTOM.IND=CUSTOM.IND, est=est, longpars=longpars, pars=pars,
                                ngroups=ngroups, J=J, gTheta=gTheta, PrepList=PrepList, L=L,
@@ -256,13 +256,12 @@ Mstep.grad_alt <- function(x0, optim_args){
 }
 
 Mstep.NR <- function(p, est, longpars, pars, ngroups, J, gTheta, PrepList, L, ANY.PRIOR,
-                     constrain, LBOUND, UBOUND, itemloc, DERIV, rlist, SLOW.IND, TOL, control)
+                     constrain, LBOUND, UBOUND, itemloc, DERIV, rlist, SLOW.IND, control)
 {
     plast2 <- plast <- p
     ubound <- UBOUND[est]
     lbound <- LBOUND[est]
     lastchange <- 0
-    if(is.null(control$maxit)) control$maxit <- 50L
     for(iter in 1L:control$maxit){
         longpars[est] <- p
         longpars <- longpars_constrain(longpars=longpars, constrain=constrain)
@@ -302,10 +301,12 @@ Mstep.NR <- function(p, est, longpars, pars, ngroups, J, gTheta, PrepList, L, AN
             flip <- (sign(lastchange) * sign(change)) == -1L
             p[flip] <- (plast[flip] + p[flip]) / 2
         }
-        p[p > ubound] <- ubound[p > ubound]
-        p[p < lbound] <- lbound[p < lbound]
+        if(any(p < lbound))
+            p[p < lbound] <- (plast[p < lbound] + lbound[p < lbound])/2
+        if(any(p > ubound))
+            p[p > ubound] <- (plast[p > ubound] + ubound[p > ubound])/2
         dif <- plast - p
-        if(all(abs(dif) < TOL)) break
+        if(all(abs(dif) < control$tol)) break
         lastchange <- change
     }
     return(list(par=p))
