@@ -11,6 +11,10 @@ void P_graded(vector<double> &, const vector<double> &,
     const NumericMatrix &, const NumericVector &, const int &,
     const int &, const int &, const int &, const int &);
 
+void P_gpcmIRT(vector<double> &, const vector<double> &,
+    const NumericMatrix &, const NumericVector &, const int &,
+    const int &, const int &);
+
 void P_nominal(vector<double> &, const vector<double> &,
     const NumericMatrix &, const NumericVector &, const int &,
     const int &, const int &, const int &, const int &);
